        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>7</strong> miembros: 18 <br>2,5,6,7,8,11,13,19,20,21,28,31,32,34,35,37,43,48';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>25</strong> miembros: 16 <strong>control</strong><br>0,1,4,10,12,15,17,18,25,26,33,36,38,46,49,50';}
       if(rr==5 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>16</strong> miembros: 10 <br>3,9,14,16,23,24,29,39,40,44';}
       if(rr==5 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260510 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>4</strong> representante: <strong>45</strong> miembros: 7 <br>22,27,30,41,42,45,47';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260510 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260510 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>7</strong> miembros: 18 <br>2,5,6,7,8,11,13,19,20,21,28,31,32,34,35,37,43,48';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260510 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>25</strong> miembros: 16 <strong>control</strong><br>0,1,4,10,12,15,17,18,25,26,33,36,38,46,49,50';}
       if(rr==40 && cc==3){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260510 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>16</strong> miembros: 10 <br>3,9,14,16,23,24,29,39,40,44';}
       if(rr==40 && cc==4){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260510 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>4</strong> representante: <strong>45</strong> miembros: 7 <br>22,27,30,41,42,45,47';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260510 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260510 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>7</strong> miembros: 18 <br>2,5,6,7,8,11,13,19,20,21,28,31,32,34,35,37,43,48';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260510 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>25</strong> miembros: 16 <strong>control</strong><br>0,1,4,10,12,15,17,18,25,26,33,36,38,46,49,50';}
       if(rr==41 && cc==3){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260510 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>16</strong> miembros: 10 <br>3,9,14,16,23,24,29,39,40,44';}
       if(rr==41 && cc==4){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260510 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>4</strong> representante: <strong>45</strong> miembros: 7 <br>22,27,30,41,42,45,47';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260510 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260510 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>7</strong> miembros: 18 <br>2,5,6,7,8,11,13,19,20,21,28,31,32,34,35,37,43,48';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260510 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>25</strong> miembros: 16 <strong>control</strong><br>0,1,4,10,12,15,17,18,25,26,33,36,38,46,49,50';}
       if(rr==42 && cc==3){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260510 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>16</strong> miembros: 10 <br>3,9,14,16,23,24,29,39,40,44';}
       if(rr==42 && cc==4){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260510 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>4</strong> representante: <strong>45</strong> miembros: 7 <br>22,27,30,41,42,45,47';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260510 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260510 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>7</strong> miembros: 18 <br>2,5,6,7,8,11,13,19,20,21,28,31,32,34,35,37,43,48';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260510 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>25</strong> miembros: 16 <strong>control</strong><br>0,1,4,10,12,15,17,18,25,26,33,36,38,46,49,50';}
       if(rr==43 && cc==3){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260510 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>16</strong> miembros: 10 <br>3,9,14,16,23,24,29,39,40,44';}
       if(rr==43 && cc==4){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260510 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>4</strong> representante: <strong>45</strong> miembros: 7 <br>22,27,30,41,42,45,47';}
}
